package lockmgr;

public interface ILockManager {
	
	/**
	 * Locks a data object in read or write mode blocking the caller if lock cannot be acquired.
	 * @param xid The id of the transaction on which behalf the data object should be locked
	 * @param strData The unique name of the data object
	 * @param lockType The type of lock which is to be acquired (read or write lock)
	 * @return true
	 * @throws DeadlockException thrown if a cycle will occur in the waiting graph due to this operation
	 */
	public boolean lock(int xid, String strData, LockType lockType)
	throws DeadlockException;
	
	/**
	 * Releases all locks held by the specified transaction.
	 * @param xid The id of the transaction 
	 * @return true
	 */
	public boolean unlockAll(int xid);

}
