package transaction;

import java.rmi.Remote;
import java.rmi.RemoteException;

public interface ITransactionManager extends Remote {
	
	public static final String RMI_TM_NAME = "tm";

	/**
	 * Begin a new distributed transaction.
	 * @return a globally unique transaction id 
	 * @throws RemoteException
	 */
	public int begin() throws RemoteException;

	/**
	 * Commit a distributed transaction. Initializes the 2PC protocol.
	 * @param globalXID the id of the distributed transaction
	 * @return true on success, false otherwise
	 * @throws TransactionAbortedException
	 * @throws InvalidTransactionException
	 * @throws RemoteException
	 */
	public boolean commit(int globalXID) throws TransactionAbortedException,
			InvalidTransactionException, RemoteException;

	/**
	 * Abort a distributed transaction.
	 * @param globalXID the id of the distributed transaction
	 * @return true on success, false otherwise
	 * @throws TransactionAbortedException
	 * @throws InvalidTransactionException
	 * @throws RemoteException
	 */
	public boolean abort(int globalXID) throws TransactionAbortedException,
			InvalidTransactionException, RemoteException;
	
	/**
	 * Enlist a resource manager with the given name to the list
	 * of participants for the given distributed transaction. 
	 * @param resourceManagerRMIName the RMI name of the RM
	 * @param globalXID the id of the distributed transaction
	 * @return true on success, false otherwise
	 */
	public boolean enlist(String resourceManagerRMIName, int globalXID);

}
